<?php

namespace App\Controllers;

use App\Models\Model_DataDasar;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PhpOffice\PhpSpreadsheet\Calculation\Engine\FormattedNumber;

date_default_timezone_set("Asia/Jakarta");

class Data_Dasar extends BaseController
{

    public function __construct()
    {
        $this->Model_DataDasar = new Model_DataDasar();
    }

    // public function Json_Dengan_Tombol() {
    //     return datatables('tbl_tarif')
    //     ->select('kode_tarif, instalasi_induk, instalasi_pelaksana, kode_klp, klp_tindakan, nama_tindakan, detail_tindakan, biaya, jasa, tarif')
    //     ->editColumn('biaya', function($biaya) {
    //         return format_rupiah($biaya);
    //     })
    //     ->editColumn('jasa', function($jasa) {
    //         return format_rupiah($jasa);
    //     })
    //     ->editColumn('tarif', function($tarif) {
    //         return format_rupiah($tarif);
    //     })
    //     ->addColumn('edit', function($data) {
    //         return "<button type=\"button\" class=\"btn btn-xs btn-primary\" class=\"btn btn-sm btn-primary\"><i class=\"fa fa-xs fa-search mr-1\"></i> Buka</button>";
    //     })
    //     ->rawColumns(['edit'])
    //     ->make();
    // }

    public function Json_Tarif() {
        return datatables('tbl_tarif')
        ->select('kode_tarif, instalasi_induk, instalasi_pelaksana, kode_klp, klp_tindakan, nama_tindakan, detail_tindakan, biaya, jasa, tarif')
        ->editColumn('biaya', function($biaya) {
            return format_rupiah($biaya);
        })
        ->editColumn('jasa', function($jasa) {
            return format_rupiah($jasa);
        })
        ->editColumn('tarif', function($tarif) {
            return format_rupiah($tarif);
        })
        ->make();
    }

    // perintah tampilkan tarif
    public function Data_Tarif()
    {
        $data = [
            'judul_web' => 'Data Tarif',
            'judul_halaman' => 'Data Tarif',
            'isi'    => 'data_dasar/tarif',
            // 'tarif' => $this->Model_DataDasar->data_tarif(),
        ];
        return view('layout/v_template', $data);
    }


    //perintah import data excel
    public function Import_Tarif()
    {
        $file = $this->request->getFile('file_excel');
        $extension = $file->getClientExtension();
        if ($extension == 'xlsx' || $extension == 'xls') {
            if ($extension == 'xls') {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xls();
            } else {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();
            }
            $spreadsheet = $reader->load($file);
            $biaya = $spreadsheet->getActiveSheet()->toArray();

            foreach ($biaya as $key => $baris) {
                if ($key == 0) {
                    continue;
                }
                $data = [
                    'kode_tarif' => $baris[0],
                    'instalasi_induk' => $baris[1],
                    'instalasi_pelaksana' => $baris[2],
                    'kode_klp' => $baris[3],
                    'klp_tindakan' => $baris[4],
                    'nama_tindakan' => $baris[5],
                    'detail_tindakan' => $baris[6],
                    'biaya' => $baris[7],
                    'jasa' => $baris[8],
                    'tarif' => $baris[9],
                ];
                $this->Model_DataDasar->simpan_tarif($data);
            }
            session()->setFlashdata('pesan', 'Data Tarif Berhasil Diunggah');
            return redirect()->to(base_url('Data_Dasar/Data_Tarif'));
        }
    }


    //perintah export data excel
    public function Export_Tarif()
    {
        $tarif = $this->Model_DataDasar->data_tarif();

        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();
        $sheet->setCellValue('A1', 'Kode Tarif');
        $sheet->setCellValue('B1', 'Inst. Induk');
        $sheet->setCellValue('C1', 'Inst. pelaksana');
        $sheet->setCellValue('D1', 'Kode Klp');
        $sheet->setCellValue('E1', 'Klp. Tindakan');
        $sheet->setCellValue('F1', 'Nama Tindakan');
        $sheet->setCellValue('G1', 'Detail Tindakan');
        $sheet->setCellValue('H1', 'Biaya');
        $sheet->setCellValue('I1', 'Jasa');
        $sheet->setCellValue('J1', 'Tarif');

        $column = 2;
        foreach ($tarif as $baris) {
            $sheet->setCellValue('A' . $column, $baris['kode_tarif']);
            $sheet->setCellValue('B' . $column, $baris['instalasi_induk']);
            $sheet->setCellValue('C' . $column, $baris['instalasi_pelaksana']);
            $sheet->setCellValue('D' . $column, $baris['kode_klp']);
            $sheet->setCellValue('E' . $column, $baris['klp_tindakan']);
            $sheet->setCellValue('F' . $column, $baris['nama_tindakan']);
            $sheet->setCellValue('G' . $column, $baris['detail_tindakan']);
            $sheet->setCellValue('H' . $column, $baris['biaya']);
            $sheet->setCellValue('I' . $column, $baris['jasa']);
            $sheet->setCellValue('J' . $column, $baris['tarif']);
            $column++;
        }
        $sheet->getColumnDimension('A')->SetAutoSize(true);
        $sheet->getColumnDimension('B')->SetAutoSize(true);
        $sheet->getColumnDimension('C')->SetAutoSize(true);
        $sheet->getColumnDimension('D')->SetAutoSize(true);
        $sheet->getColumnDimension('E')->SetAutoSize(true);
        $sheet->getColumnDimension('F')->SetAutoSize(true);
        $sheet->getColumnDimension('G')->SetAutoSize(true);
        $sheet->getColumnDimension('H')->SetAutoSize(true);
        $sheet->getColumnDimension('I')->SetAutoSize(true);
        $sheet->getColumnDimension('J')->SetAutoSize(true);

        $writer = new Xlsx($spreadsheet);
        header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        header('Content-Disposition: attachment;filename=data_tarif.xlsx');
        $writer->save('php://output');
        exit();
    }


    //Menggunakan Irsyadulibad ServerSide DataTables

    public function Json_Kelompok_Tindakan() {
        return datatables('tbl_detailtindakan')->make();
    }

    public function Kelompok_Tindakan()
    {
        $data = [
            'judul_web' => 'Kelompok Tindakan',
            'judul_halaman' => 'Kelompok Tindakan',
            'isi'    => 'data_dasar/klptindakan',
        ];
        return view('layout/v_template', $data);
    }

    //perintah import data excel
    public function Import_KlpTindakan()
    {
        $file = $this->request->getFile('file_excel');
        $extension = $file->getClientExtension();
        if ($extension == 'xlsx' || $extension == 'xls') {
            if ($extension == 'xls') {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xls();
            } else {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();
            }
            $spreadsheet = $reader->load($file);
            $biaya = $spreadsheet->getActiveSheet()->toArray();

            foreach ($biaya as $key => $baris) {
                if ($key == 0) {
                    continue;
                }
                $data = [
                    'kode_tindakan' => $baris[0],
                    'kode_tarif' => $baris[1],
                    'instalasi_induk' => $baris[2],
                    'instalasi_pelaksana' => $baris[3],
                    'klinik_ksm' => $baris[4],
                    'klp_tindakan' => $baris[5],
                    'detail_tindakan' => $baris[6],
                    'rincian_tindakan' => $baris[7],
                ];
                $this->Model_DataDasar->simpan_klptindakan($data);
            }
            session()->setFlashdata('pesan', 'Data Kelompok Tindakan Berhasil Diunggah');
            return redirect()->to(base_url('Data_Dasar/Kelompok_Tindakan'));
        }
    }


    //perintah export data excel
    public function Export_KlpTindakan()
    {
        $tarif = $this->Model_DataDasar->data_klptindakan();

        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();
        $sheet->setCellValue('A1', 'Kode Tind');
        $sheet->setCellValue('B1', 'Kode Tarif');
        $sheet->setCellValue('C1', 'Inst. Induk');
        $sheet->setCellValue('D1', 'Inst. pelaksana');
        $sheet->setCellValue('E1', 'Klinik/KSM');
        $sheet->setCellValue('F1', 'Klp. Tindakan');
        $sheet->setCellValue('G1', 'Nama Tindakan');
        $sheet->setCellValue('H1', 'Detail Tindakan');

        $column = 2;
        foreach ($tarif as $baris) {
            $sheet->setCellValue('A' . $column, $baris['kode_tindakan']);
            $sheet->setCellValue('B' . $column, $baris['kode_tarif']);
            $sheet->setCellValue('C' . $column, $baris['instalasi_induk']);
            $sheet->setCellValue('D' . $column, $baris['instalasi_pelaksana']);
            $sheet->setCellValue('E' . $column, $baris['klinik_ksm']);
            $sheet->setCellValue('F' . $column, $baris['klp_tindakan']);
            $sheet->setCellValue('G' . $column, $baris['detail_tindakan']);
            $sheet->setCellValue('H' . $column, $baris['rincian_tindakan']);
            $column++;
        }
        $sheet->getColumnDimension('A')->SetAutoSize(true);
        $sheet->getColumnDimension('B')->SetAutoSize(true);
        $sheet->getColumnDimension('C')->SetAutoSize(true);
        $sheet->getColumnDimension('D')->SetAutoSize(true);
        $sheet->getColumnDimension('E')->SetAutoSize(true);
        $sheet->getColumnDimension('F')->SetAutoSize(true);
        $sheet->getColumnDimension('G')->SetAutoSize(true);
        $sheet->getColumnDimension('H')->SetAutoSize(true);


        $writer = new Xlsx($spreadsheet);
        header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        header('Content-Disposition: attachment;filename=kelompok_tindakan.xlsx');
        $writer->save('php://output');
        exit();
    }



    // Ruang
    public function Ruang()
    {
        $data = [
            'judul_web' => 'Ruang Unit',
            'judul_halaman' => 'Ruang Unit',
            'isi'    => 'data_dasar/ruang',
            'data_ruang' => $this->Model_DataDasar->data_ruang(),
        ];
        return view('layout/v_template', $data);
    }


    //perintah import data excel
    public function Import_Ruang()
    {
        $file = $this->request->getFile('file_excel');
        $extension = $file->getClientExtension();
        if ($extension == 'xlsx' || $extension == 'xls') {
            if ($extension == 'xls') {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xls();
            } else {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();
            }
            $spreadsheet = $reader->load($file);
            $biaya = $spreadsheet->getActiveSheet()->toArray();

            foreach ($biaya as $key => $baris) {
                if ($key == 0) {
                    continue;
                }
                $data = [
                    'kode' => $baris[0],
                    'ruang' => $baris[1],
                    'instalasi' => $baris[2],
                ];
                $this->Model_DataDasar->simpan_ruang($data);
            }
            session()->setFlashdata('pesan', 'Data Ruang Berhasil Diunggah');
            return redirect()->to(base_url('Data_Dasar/Ruang'));
        }
    }


    //perintah export data excel
    public function Export_Ruang()
    {
        $tarif = $this->Model_DataDasar->data_ruang();

        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();
        $sheet->setCellValue('A1', 'Kode');
        $sheet->setCellValue('B1', 'Ruangan');
        $sheet->setCellValue('C1', 'Instalasi');

        $column = 2;
        foreach ($tarif as $baris) {
            $sheet->setCellValue('A' . $column, $baris['kode']);
            $sheet->setCellValue('B' . $column, $baris['ruang']);
            $sheet->setCellValue('C' . $column, $baris['instalasi']);
            $column++;
        }
        $sheet->getColumnDimension('A')->SetAutoSize(true);
        $sheet->getColumnDimension('B')->SetAutoSize(true);
        $sheet->getColumnDimension('C')->SetAutoSize(true);

        $writer = new Xlsx($spreadsheet);
        header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        header('Content-Disposition: attachment;filename=ruang.xlsx');
        $writer->save('php://output');
        exit();
    }


    // Pelaksana
    public function Pelaksana()
    {
        $data = [
            'judul_web' => 'Pelaksana',
            'judul_halaman' => 'Pelaksana',
            'isi'    => 'data_dasar/pelaksana',
            'data_pelaksana' => $this->Model_DataDasar->data_pelaksana(),
        ];
        return view('layout/v_template', $data);
    }


    //perintah import data excel
    public function Import_Pelaksana()
    {
        $file = $this->request->getFile('file_excel');
        $extension = $file->getClientExtension();
        if ($extension == 'xlsx' || $extension == 'xls') {
            if ($extension == 'xls') {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xls();
            } else {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();
            }
            $spreadsheet = $reader->load($file);
            $biaya = $spreadsheet->getActiveSheet()->toArray();

            foreach ($biaya as $key => $baris) {
                if ($key == 0) {
                    continue;
                }
                $data = [
                    'kode' => $baris[0],
                    'nama' => $baris[1],
                    'unit' => $baris[2],
                ];
                $this->Model_DataDasar->simpan_pelaksana($data);
            }
            session()->setFlashdata('pesan', 'Data Pelaksana Berhasil Diunggah');
            return redirect()->to(base_url('Data_Dasar/Pelaksana'));
        }
    }


    //perintah export data excel
    public function Export_Pelaksana()
    {
        $tarif = $this->Model_DataDasar->data_pelaksana();

        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();
        $sheet->setCellValue('A1', 'Kode');
        $sheet->setCellValue('B1', 'Nama Pelaksana');
        $sheet->setCellValue('C1', 'Ruang/Unit');

        $column = 2;
        foreach ($tarif as $baris) {
            $sheet->setCellValue('A' . $column, $baris['kode']);
            $sheet->setCellValue('B' . $column, $baris['nama']);
            $sheet->setCellValue('C' . $column, $baris['unit']);
            $column++;
        }
        $sheet->getColumnDimension('A')->SetAutoSize(true);
        $sheet->getColumnDimension('B')->SetAutoSize(true);
        $sheet->getColumnDimension('C')->SetAutoSize(true);

        $writer = new Xlsx($spreadsheet);
        header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        header('Content-Disposition: attachment;filename=pelaksana.xlsx');
        $writer->save('php://output');
        exit();
    }



    // Pendamping
    public function Pendamping()
    {
        $data = [
            'judul_web' => 'Pendamping',
            'judul_halaman' => 'Pendamping',
            'isi'    => 'data_dasar/pendamping',
            'data_pendamping' => $this->Model_DataDasar->data_pendamping(),
        ];
        return view('layout/v_template', $data);
    }


    //perintah import data excel
    public function Import_Pendamping()
    {
        $file = $this->request->getFile('file_excel');
        $extension = $file->getClientExtension();
        if ($extension == 'xlsx' || $extension == 'xls') {
            if ($extension == 'xls') {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xls();
            } else {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();
            }
            $spreadsheet = $reader->load($file);
            $biaya = $spreadsheet->getActiveSheet()->toArray();
            // print_r($obat);

            foreach ($biaya as $key => $baris) {
                if ($key == 0) {
                    continue;
                }
                $data = [
                    'kode' => $baris[0],
                    'nama' => $baris[1],
                    'unit' => $baris[2],
                ];
                $this->Model_DataDasar->simpan_pendamping($data);
            }
            session()->setFlashdata('pesan', 'Data Pendamping Berhasil Diunggah');
            return redirect()->to(base_url('Data_Dasar/Pendamping'));
        }
    }


    //perintah export data excel
    public function Export_Pendamping()
    {
        $tarif = $this->Model_DataDasar->data_pendamping();

        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();
        $sheet->setCellValue('A1', 'Kode');
        $sheet->setCellValue('B1', 'Nama Pendamping');
        $sheet->setCellValue('C1', 'Ruang/Unit');

        $column = 2;
        foreach ($tarif as $baris) {
            $sheet->setCellValue('A' . $column, $baris['kode']);
            $sheet->setCellValue('B' . $column, $baris['nama']);
            $sheet->setCellValue('C' . $column, $baris['unit']);
            $column++;
        }
        $sheet->getColumnDimension('A')->SetAutoSize(true);
        $sheet->getColumnDimension('B')->SetAutoSize(true);
        $sheet->getColumnDimension('C')->SetAutoSize(true);

        $writer = new Xlsx($spreadsheet);
        header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        header('Content-Disposition: attachment;filename=pendamping.xlsx');
        $writer->save('php://output');
        exit();
    }


    // Porsi JP
    public function Porsi_JP()
    {
        $data = [
            'judul_web' => 'Porsi Jasa Pelayanan',
            'judul_halaman' => 'Porsi Jasa Pelayanan',
            'isi'    => 'data_dasar/porsi_jp',
            'porsi_jp' => $this->Model_DataDasar->porsi_jp(),
        ];
        return view('layout/v_template', $data);
    }


    //perintah import data excel
    public function Import_PorsiJP()
    {
        $file = $this->request->getFile('file_excel');
        $extension = $file->getClientExtension();
        if ($extension == 'xlsx' || $extension == 'xls') {
            if ($extension == 'xls') {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xls();
            } else {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();
            }
            $spreadsheet = $reader->load($file);
            $biaya = $spreadsheet->getActiveSheet()->toArray();
            // print_r($obat);

            foreach ($biaya as $key => $baris) {
                if ($key == 0) {
                    continue;
                }
                $data = [
                    'kode_kelompok' => $baris[0],
                    'instalasi_induk' => $baris[1],
                    'instalasi_pelaksana' => $baris[2],
                    'kelompok_tindakan' => $baris[3],
                    'JL_Pelaksana' => $baris[4],
                    'JL_Asisten' => $baris[5],
                    'JTL_Struktural' => $baris[6],
                    'JTL_Pegawai' => $baris[7],
                    'istmno' => $baris[8],
                ];
                $this->Model_DataDasar->simpan_porsijp($data);
            }
            session()->setFlashdata('pesan', 'Data Porsi JP Berhasil Diunggah');
            return redirect()->to(base_url('Data_Dasar/Porsi_JP'));
        }
    }


    //perintah export data excel
    public function Export_PorsiJP()
    {
        $tarif = $this->Model_DataDasar->porsi_jp();

        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();
        $sheet->setCellValue('A1', 'Kode');
        $sheet->setCellValue('B1', 'Instalasi Induk');
        $sheet->setCellValue('C1', 'Instalasi Pelaksana');
        $sheet->setCellValue('D1', 'Kelompok Tindakan');
        $sheet->setCellValue('E1', 'JL Pelaksana');
        $sheet->setCellValue('F1', 'JL Pendamping');
        $sheet->setCellValue('G1', 'JTL Manajemen');
        $sheet->setCellValue('H1', 'JTL Pegawai');
        $sheet->setCellValue('I1', 'TMO-TMNO');

        $column = 2;
        foreach ($tarif as $baris) {
            $sheet->setCellValue('A' . $column, $baris['kode_kelompok']);
            $sheet->setCellValue('B' . $column, $baris['instalasi_induk']);
            $sheet->setCellValue('C' . $column, $baris['instalasi_pelaksana']);
            $sheet->setCellValue('D' . $column, $baris['kelompok_tindakan']);
            $sheet->setCellValue('E' . $column, $baris['JL_Pelaksana']);
            $sheet->setCellValue('F' . $column, $baris['JL_Asisten']);
            $sheet->setCellValue('G' . $column, $baris['JTL_Struktural']);
            $sheet->setCellValue('H' . $column, $baris['JTL_Pegawai']);
            $sheet->setCellValue('I' . $column, $baris['istmno']);
            $column++;
        }
        $sheet->getColumnDimension('A')->SetAutoSize(true);
        $sheet->getColumnDimension('B')->SetAutoSize(true);
        $sheet->getColumnDimension('C')->SetAutoSize(true);
        $sheet->getColumnDimension('D')->SetAutoSize(true);
        $sheet->getColumnDimension('E')->SetAutoSize(true);
        $sheet->getColumnDimension('F')->SetAutoSize(true);
        $sheet->getColumnDimension('G')->SetAutoSize(true);
        $sheet->getColumnDimension('H')->SetAutoSize(true);
        $sheet->getColumnDimension('I')->SetAutoSize(true);


        $writer = new Xlsx($spreadsheet);
        header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        header('Content-Disposition: attachment;filename=porsi_jp.xlsx');
        $writer->save('php://output');
        exit();
    }

    // Porsi JP TMO
    public function Porsi_JPTMO()
    {
        $data = [
            'judul_web' => 'Porsi JP TMO',
            'judul_halaman' => 'Porsi JP TMO',
            'isi'    => 'data_dasar/porsi_jptmo',
            'porsi_jptmo' => $this->Model_DataDasar->porsi_jptmo(),
        ];
        return view('layout/v_template', $data);
    }


    //perintah import data excel
    public function Import_PorsiJPTMO()
    {
        $file = $this->request->getFile('file_excel');
        $extension = $file->getClientExtension();
        if ($extension == 'xlsx' || $extension == 'xls') {
            if ($extension == 'xls') {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xls();
            } else {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();
            }
            $spreadsheet = $reader->load($file);
            $biaya = $spreadsheet->getActiveSheet()->toArray();
            // print_r($obat);

            foreach ($biaya as $key => $baris) {
                if ($key == 0) {
                    continue;
                }
                $data = [
                    'kode' => $baris[0],
                    'jenis_tmo' => $baris[1],
                    'penerima_jp' => $baris[2],
                    'porsi_jp' => $baris[3],
                ];
                $this->Model_DataDasar->simpan_porsijptmo($data);
            }
            session()->setFlashdata('pesan', 'Data Porsi JP TMO Berhasil Diunggah');
            return redirect()->to(base_url('Data_Dasar/Porsi_JPTMO'));
        }
    }


    //perintah export data excel
    public function Export_PorsiJPTMO()
    {
        $tarif = $this->Model_DataDasar->porsi_jptmo();

        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();
        $sheet->setCellValue('A1', 'Kode');
        $sheet->setCellValue('B1', 'Jenis TMO');
        $sheet->setCellValue('C1', 'Penerima JP');
        $sheet->setCellValue('D1', 'Porsi JP');

        $column = 2;
        foreach ($tarif as $baris) {
            $sheet->setCellValue('A' . $column, $baris['kode']);
            $sheet->setCellValue('B' . $column, $baris['jenis_tmo']);
            $sheet->setCellValue('C' . $column, $baris['penerima_jp']);
            $sheet->setCellValue('D' . $column, $baris['porsi_jp']);
            $column++;
        }
        $sheet->getColumnDimension('A')->SetAutoSize(true);
        $sheet->getColumnDimension('B')->SetAutoSize(true);
        $sheet->getColumnDimension('C')->SetAutoSize(true);
        $sheet->getColumnDimension('D')->SetAutoSize(true);

        $writer = new Xlsx($spreadsheet);
        header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        header('Content-Disposition: attachment;filename=porsi_jptmo.xlsx');
        $writer->save('php://output');
        exit();
    }


    // Porsi JP
    public function Porsi_Cbgs()
    {
        $data = [
            'judul_web' => 'Porsi CBGs',
            'judul_halaman' => 'Porsi CBGs',
            'isi'    => 'data_dasar/porsi_cbgs',
            'porsi_cbgs' => $this->Model_DataDasar->porsi_cbgs(),
        ];
        return view('layout/v_template', $data);
    }


    public function Simpan_Cbgs()
    {
        $data = [
            'porsi_cbgs' => $this->request->getPost('porsi_cbgs'),
            'nilai' => $this->request->getPost('nilai'),
        ];


        $this->Model_DataDasar->simpan_porsi_cbgs($data);

        session()->setFlashdata('pesan', 'Data Porsi CBGs Berhasil Diunggah');
        return redirect()->to(base_url('Data_Dasar/Porsi_Cbgs'));
    }


    // perintah Hapus Dokter
    public function Hapus_PorsiCBGs($porsi_cbgs)
    {
        $data = [
            'porsi_cbgs' => $porsi_cbgs,
        ];

        $this->Model_DataDasar->hapus_porsicbgs($data);
        session()->setFlashdata('pesan', 'Data CBGs Berhasil Dihapus');
        return redirect()->to(base_url('Data_Dasar/Porsi_Cbgs'));
    }


    public function Hapus_Databased()
    {
        $data = [
            'judul_web' => 'Hapus Database',
            'judul_halaman' => 'Hapus Database',
            'isi'    => 'data_dasar/hapus_data',
            'porsi_cbgs' => $this->Model_DataDasar->porsi_cbgs(),
        ];
        return view('layout/v_template', $data);
    }

    public function Perintah_Hapus()
    {
        $this->Model_DataDasar->hapus_data_tarif();
        $this->Model_DataDasar->hapus_data_detailtindakan();
        $this->Model_DataDasar->hapus_data_ruang();
        $this->Model_DataDasar->hapus_data_pelaksana();
        $this->Model_DataDasar->hapus_data_pendamping();
        $this->Model_DataDasar->hapus_data_porsiJP();
        $this->Model_DataDasar->hapus_data_porsiJPTMO();
        session()->setFlashdata('pesan', 'Databased Berhasil Dihapus');
        return redirect()->to(base_url('Data_Dasar/Hapus_Databased'));
    }
}
