<?php

namespace App\Controllers;

use App\Models\Model_JTL;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;

date_default_timezone_set("Asia/Jakarta");

class JTL extends BaseController
{

    public function __construct()
    {
        $this->Model_JTL = new Model_JTL();
    }

    public function Json_Indeks_Pegawai() {
        return datatables('tbl_indeks_pegawai')
        ->addColumn('hapus', function($data) {
            return "<a href=\"Detail_Indeks/$data->kode\" class=\"btn btn-xs btn-primary\" class=\"btn btn-sm btn-primary\"><i class=\"fa fa-xs fa-search mr-1\"></i> Buka</a>";
            })
        ->rawColumns(['hapus'])
        ->make();
    }


    public function Indeks_Pegawai()
    {
        $data = [
            'judul_web' => 'Indeks Pegawai',
            'judul_halaman' => 'Data Indeks Pegawai',
            'isi'    => 'jtl/indeks_pegawai',
        ];
        return view('layout/v_template', $data);
    }


    public function Detail_Indeks($kode)
    {
        $data = [
            'judul_web' => 'Data Indeks Pegawai',
            'judul_halaman' => 'Data Indeks Pegawai',
            'isi'    => 'jtl/indeks_detail',
            'detail_indeks' => $this->Model_JTL->detail_indeks($kode),
        ];
        return view('layout/v_template', $data);
    }


    //perintah import data excel
    public function Import_Indeks()
    {
        $file = $this->request->getFile('file_excel');
        $extension = $file->getClientExtension();
        if ($extension == 'xlsx' || $extension == 'xls') {
            if ($extension == 'xls') {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xls();
            } else {
                $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();
            }
            $spreadsheet = $reader->load($file);

            $indeks = $spreadsheet->getActiveSheet()->toArray();

            foreach ($indeks as $key => $baris) {
                if ($key == 0) {
                    continue;
                }
                $data = [
                    'kode' => $baris[0],
                    'nama' => $baris[1],
                    'ruang' => $baris[2],
                    'dasar' => $baris[3],
                    'kompetensi' => $baris[4],
                    'resiko' => $baris[5],
                    'emergensi' => $baris[6],
                    'posisi' => $baris[7],
                    'kinerja' => $baris[8],
                    'jumlah' => $baris[9],
                    'pajak' => $baris[10],
                ];
                $this->Model_JTL->simpan_indeks($data);
            }
            session()->setFlashdata('pesan', 'Data Indeks Pegawai Berhasil Diunggah');
            return redirect()->to(base_url('JTL/Indeks_Pegawai'));
        }
    }


    public function Hapus_Data_Indeks()
    {
        $this->Model_JTL->hapus_data_indeks();
        session()->setFlashdata('pesan', 'Databased Berhasil Dihapus');
        return redirect()->to(base_url('JTL/Indeks_Pegawai'));
    }


    public function Edit_Indeks($kode)
    {
        $data = [
            'kode' => $this->request->getPost('kode'),
            'nama' => $this->request->getPost('nama'),
            'dasar' => $this->request->getPost('dasar'),
            'kompetensi' => $this->request->getPost('kompetensi'),
            'resiko' => $this->request->getPost('resiko'),
            'emergensi' => $this->request->getPost('emergensi'),
            'posisi' => $this->request->getPost('posisi'),
            'kinerja' => $this->request->getPost('kinerja'),
            'jumlah' => $this->request->getPost('jumlah'),
            'pajak' => $this->request->getPost('pajak'),
        ];
        $this->Model_JTL->edit_indeks($data, $kode);
        session()->setFlashdata('pesan', 'Data Indeks Pegawai Berhasil Diubah');
        return redirect()->to(base_url('JTL/Indeks_Pegawai'));
    }

    
    // perintah hapus data tarif
    public function Hapus_Indeks($kode)
    {
        $data = [
            'kode' => $kode,
        ];

        $this->Model_JTL->hapus_indeks($data);
        session()->setFlashdata('pesan', 'Data Pegawai Berhasil Dihapus');
        return redirect()->to(base_url('JTL/Indeks_Pegawai'));
    }


    public function Indeks_Bulanan()
    {
        $data = [
            'judul_web' => 'Indeks Pegawai Bulanan',
            'judul_halaman' => 'Data Indeks Pegawai Bulanan',
            'isi'    => 'jtl/indeks_pegawai_bulanan',
            'indeks_bulanan' => $this->Model_JTL->indeks_bulanan(),
            'jumlah_indeks_bulanan' => $this->Model_JTL->jumlah_indeks_bulanan(),

        ];
        return view('layout/v_template', $data);
    }


    public function Simpan_Indeks()
    {
        $request = \Config\Services::request();
        $data = $request->getPost('data');

        // print_r($data);
        $Qcek = $this->Model_JTL->cek_indeks_bulanan();

        if ($Qcek[0]['total'] > 0) {
            echo json_encode(array('msg' => 'Data Sudah Ada. Tidak Bisa Simpan Ulang', 'code' => "00"));
        } else {
            foreach (json_decode($data) as $row) {
                $data = [
                    'tahun' => $row[0],
                    'bulan' => $row[1],
                    'kode' => $row[2],
                    'nama' => $row[3],
                    'ruang' => $row[4],
                    'jumlah' => $row[5],
                    'pajak' => $row[6],
                ];

                $this->Model_JTL->simpan_indeks_bulanan($data);
            }
            echo json_encode(array('msg' => "Data Berhasil Disimpan", 'code' => "99"));
        }
    }


    public function Simpan_Jumlah_IndeksBulanan()
    {
        $data = [
            'tahun' => $this->request->getPost('tahun'),
            'bulan' => $this->request->getPost('bulan'),
            'jumlah' => $this->request->getPost('jumlah'),
        ];
        $this->Model_JTL->simpan_jumlah_indeksbulanan($data);
        session()->setFlashdata('pesan', 'Jumlah Indeks Berhasil Ditambah');
        return redirect()->to(base_url('JTL/Indeks_Bulanan'));
    }


    public function Hapus_Data_IndeksBulanan()
    {
        $this->Model_JTL->hapus_data_indeksbulanan();
        $this->Model_JTL->hapus_jumlah_indekspegawai();
        session()->setFlashdata('pesan', 'Databased Berhasil Dihapus');
        return redirect()->to(base_url('JTL/Indeks_Bulanan'));
    }


    public function Nilai_Indeks()
    {
        $request = \Config\Services::request();
        $bulan = $request->getPost('bulan');
        $data = [
            'judul_web' => 'Nilai Indeks',
            'judul_halaman' => 'Nilai Indeks',
            'isi'    => 'jtl/nilai_indeks',
            'bulan' => $bulan,
            'no_otomatis' => $this->Model_JTL->no_otomatis(),
            'nilai_indeks' => $this->Model_JTL->nilai_indeks(),
            'jumlah_indeks' => $this->Model_JTL->jumlah_indeks($bulan),
        ];
        return view('layout/v_template', $data);
    }


    //Perintah Ambil Data Pasien
    public function Ambil_Indeks($bulan)
    {
        $model = new Model_JTL();
        $query = $model->jumlah_indeks($bulan);
        $data = $query[0];
        $data['success'] = true;
        $data['message'] = 'success';
        echo json_encode($data);
    }


    public function Simpan_Nilai_Indeks()
    {
        $data = [
            'nomer' => $this->request->getPost('nomer'),
            'tahun' => $this->request->getPost('tahun'),
            'bulan' => $this->request->getPost('bulan'),
            'jumlah_indeks' => $this->request->getPost('jumlah_indeks'),
            'jumlah_jtl' => $this->request->getPost('jumlah_jtl'),
            'nilai_indeks' => $this->request->getPost('nilai_indeks'),
        ];

        $this->Model_JTL->simpan_nilai_indeks($data);
        session()->setFlashdata('pesan', 'Nilai Indeks Berhasil Ditambah');
        return redirect()->to(base_url('JTL/Nilai_Indeks'));
    }


    public function Hapus_Nilai_Indeks($nomer)
    {
        $data = [
            'nomer' => $nomer,
        ];

        $this->Model_JTL->hapus_nilai_indeks($data);
        session()->setFlashdata('pesan', 'Nilai Indeks Berhasil Dihapus');
        return redirect()->to(base_url('JTL/Nilai_Indeks'));
    }

    
    public function Hasil_JTL()
    {
        $request = \Config\Services::request();
        $tahun = $request->getPost('tahun');
        $bulan = $request->getPost('bulan');
        $hasil_jtl = $this->Model_JTL->hasil_jtl($tahun, $bulan);
        $total_jtl_bruto = $this->Model_JTL->total_jtl_bruto($tahun, $bulan);
        $total_potongan = $this->Model_JTL->total_potongan($tahun, $bulan);
        $total_jtl_net = $this->Model_JTL->total_jtl_net($tahun, $bulan);

        $data = [
            'judul_web' => 'Jasa Tidak Langsung (JTL)',
            'judul_halaman' => 'Jasa Tidak Langsung (JTL)',
            'isi'    => 'jtl/hasil_jtl',
            'tahun' => $tahun,
            'bulan' => $bulan,
            'hasil_jtl' => $hasil_jtl,
            'total_jtl_bruto' => $total_jtl_bruto,
            'total_potongan' => $total_potongan,
            'total_jtl_net' => $total_jtl_net,
        ];
        return view('layout/v_template', $data);
    }
}
